#Title: Integrated evidence-based extent of occurrence for 
#North American bison since 1500 CE and before

#Authors: Jeff M. Martin, Rachel A. Short, Glenn E. Plumb,
#Lauren Markewicz, Dirk H. Van Vuren, Bradly Wehus-Tow, 
#Erik Otarola-Castillo, and Matthew E. Hill, Jr.

#Date: 12 July 2022

#Install packages for code
install.packages("sf", "ggplot2", "sfheaders", "sp")
library(sf)
library(ggplot2)
library(sfheaders)
library(sp)

#First, read in geographic data.
#To produce the maps, this code uses shapefiles for North America, including 
#the outline and the countries, and the Great Lakes. These shapefiles are 
#available online.

northamerica <- st_read("geography/polygons/NorthAmerica_polygon.shp")
countries <- st_read("geography/polygons/NorthAmerica_Countries.shp")
lakes <- st_read("geography/polygons/Great_Lakes.shp")
bison <- read.csv("C:/Users/short/Dropbox (Personal)/Publishing Papers/IUCN bison/bison_presence_dataset (1).csv", header = TRUE)


northamerica <- st_read("NorthAmerica_polygon.shp")
northamerica <- st_crop(northamerica, xmin = -180, ymin = 0, xmax = 0, ymax = 90)

countries <- st_read("NorthAmerica_Countries.shp")
countries <- st_transform(countries, st_crs(northamerica))
countries <- st_intersection(countries, northamerica)

lakes <- st_read("Great_Lakes.shp")
lakes <- st_transform(lakes, st_crs(northamerica))

#Read in geographic points of bison data.
bison <- read.csv("bison_presence_dataset (1).csv", header = TRUE)
bison.sf <- st_as_sf(bison, coords = c(2,3), crs = st_crs(northamerica))

#To construct the maps, create a list of variables and their categories
values <- list()
#color of the point
values[[1]] <- c("black", "gray70")
#shape of the point:
values[[2]] <- 16
#dataset
values[[3]] <- c("Historical", "Archaeological", "Paleontological")
#legend labels
values[[4]] <- c("After 1500", "Before 1500")

#To make the map, insert the code for the appropriate dataset.
#1 = Historical, 2 = Archaeological, 3 = Paleontological
code <- 1
map <- ggplot() +
  geom_sf(data = countries, fill = "gray96", color = "black", lwd = 0.25) +
  geom_sf(data = lakes, fill = "white", color = "black", lwd = 0.25) +
  #The next line is only for Archaeological and Paleontological maps. It should
  #be commented out for the Historical map.
  #geom_sf(data = bison.sf[which(bison.sf$code == code & bison.sf$year < 1500), ], 
  #     aes(color = values[[1]][2]), shape = values[[2]], size = 1.25) +
  geom_sf(data = bison.sf[which(bison.sf$code == code & bison.sf$year > 1499), ], 
          aes(color = values[[1]][1]), shape = values[[2]], size = 1.25) +
  theme_void() +
  scale_color_manual(values = values[[1]],
                       name = values[[3]][code],
                     labels = values[[4]]) +
  scale_shape_manual(values = values[[2]], 
                     name = values[[3]][code],
                     labels = values[[4]]) +
  theme(legend.position = c(0.1, 0.4), legend.justification = "left", legend.title = element_text(size = 12), 
        legend.text = element_text(size = 10), legend.key.size = unit(1, "line"), 
        legend.background = element_rect(fill = "white", linetype = "solid", color = "white")) +
  guides(color = guide_legend(override.aes = list(size = 2))) +
  geom_sf(data = northamerica, fill = NA, color = "black", lwd = 0.25)
map


#Then, construct the convex hull that represents the Historic Extent of Occurrence
#The hull is constructed around points from 1500 to today.
dat <- as.matrix(bison[bison$year > 1499, 2:3])
ch <- chull(dat)

#Extract coordinates of the vertices of the hull.
coords <- dat[c(ch, ch[1]), ]
coords.df <- as.data.frame(coords)
coords.sf <- st_as_sf(coords.df, coords = c(1, 2), crs = st_crs(northamerica))
coords.sf <- st_transform(coords.sf, st_crs(northamerica))

#Plot the data and hull.
plot(dat, pch = 16)
lines(coords, col = "red")

#Finally, convert the polygon to a shapefile and limit it to the 
#extent of terrestrial North America.
poly.sf <- sf_polygon(obj = coords, x = "longitude", y = "latitude")
st_crs(poly.sf) <- st_crs(northamerica)
polygon <- rgeos::gIntersection(as_Spatial(poly.sf), as_Spatial(northamerica))
polygon <- rgeos::gDifference(polygon, as_Spatial(lakes))
polygon <- SpatialPolygonsDataFrame(polygon, data = data.frame(ID = 1))
poly.sf <- st_as_sf(polygon)

#Map the Historic Extent of Occurrence.
map <- ggplot() +
  geom_sf(data = countries, fill = "gray96", color = "black", lwd = 0.25) +
  geom_sf(data = poly.sf, fill = "gray45", colour = NA, alpha = 0.8) +
  geom_sf(data = bison.sf[bison.sf$year > 1499, ], 
          aes(color = values[[1]][1]), shape = values[[2]], size = 1.25) +
  theme_void() +
  scale_color_manual(values = values[[1]][1],
                     name = "All",
                     labels = values[[4]][1]) +
  scale_shape_manual(values = values[[2]], 
                     name = "All",
                     labels = values[[4]][1]) +
  theme(legend.position = c(0.1, 0.4), legend.justification = "left", legend.title = element_text(size = 12), 
        legend.text = element_text(size = 10), legend.key.size = unit(1, "line"), 
        legend.background = element_rect(fill = "white", linetype = "solid", color = "white")) +
  guides(color = guide_legend(override.aes = list(size = 2))) +
  geom_sf(data = lakes, fill = "white", color = "black", lwd = 0.25) +
  geom_sf(data = northamerica, fill = NA, color = "black", lwd = 0.25)
map
